#
# spec file for package python3-docutils
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-docutils
Version:        0.12
Release:        6.5
Summary:        Python Documentation Utilities
License:        Python-2.0 and BSD-2-Clause and GPL-2.0+ and GPL-3.0+ and SUSE-Public-Domain
Group:          Development/Languages/Python
Url:            https://pypi.python.org/pypi/docutils/
Source:         https://pypi.python.org/packages/source/d/docutils/docutils-%{version}.tar.gz
# Patch0:         rpmlint-non-executable-scripts.diff
BuildRequires:  python3
BuildRequires:  python3-2to3
BuildRequires:  python3-devel
BuildRequires:  python3-nose
BuildRequires:  python3-xml
Requires:       python3-xml
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Docutils is a modular system for processing documentation into useful formats,
such as HTML, XML, and LaTeX. For input Docutils supports reStructuredText, an
easy-to-read, what-you-see-is-what-you-get plaintext markup syntax.

%prep
%setup -n docutils-%{version}
# %patch0
# Remove useless ".py" ending from executables:
for i in tools/rst*; do mv "$i" "${i/.py}-%{py3_ver}"; done
sed -i "s|'tools/\(rst.*\)\.py'|'tools/\1-%{py3_ver}'|" setup.py
# Remove shebang from non-executable files
for i in {'code_analyzer','error_reporting','punctuation_chars','smartquotes','math/latex2mathml','math/math2html'}; do 
sed -i -e "1d" "docutils/utils/$i.py"
done
sed -i -e "1d" "docutils/writers/xetex/__init__.py"

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
binaries="rst2html rst2latex rst2man rst2odt rst2odt_prepstyles rst2pseudoxml rst2s5 rst2xetex rst2xml rstpep2html"
for i in $binaries; do
    ln -s %{_bindir}/${i}-%{py3_ver} %{buildroot}%{_bindir}/${i}
done

# Fails test for now, all of them
#%check
#nosetests

%pre
# Since binaries became ghosted to be used with update-alternatives,
# we have to get rid of the old binary resulting from the
# non-update-alternativies-ified package:
binaries="rst2html rst2latex rst2man rst2odt rst2odt_prepstyles rst2pseudoxml rst2s5 rst2xetex rst2xml rstpep2html"
for i in $binaries; do
    [ -h %{_bindir}/${i} ] || rm -f %{_bindir}/${i}
done

%post
update-alternatives \
    --install %{_bindir}/rst2html rst2html %{_bindir}/rst2html-%{py3_ver} 30 \
    --slave %{_bindir}/rst2latex rst2latex %{_bindir}/rst2latex-%{py3_ver} \
    --slave %{_bindir}/rst2man rst2man %{_bindir}/rst2man-%{py3_ver} \
    --slave %{_bindir}/rst2odt rst2odt %{_bindir}/rst2odt-%{py3_ver} \
    --slave %{_bindir}/rst2odt_prepstyles rst2odt_prepstyles %{_bindir}/rst2odt_prepstyles-%{py3_ver} \
    --slave %{_bindir}/rst2pseudoxml rst2pseudoxml %{_bindir}/rst2pseudoxml-%{py3_ver} \
    --slave %{_bindir}/rst2s5 rst2s5 %{_bindir}/rst2s5-%{py3_ver} \
    --slave %{_bindir}/rst2xetex rst2xetex %{_bindir}/rst2xetex-%{py3_ver} \
    --slave %{_bindir}/rst2xml rst2xml %{_bindir}/rst2xml-%{py3_ver} \
    --slave %{_bindir}/rstpep2html rstpep2html %{_bindir}/rstpep2html-%{py3_ver}

%preun
if [ $1 -eq 0 ] ; then
    update-alternatives --remove rst2html %{_bindir}/rst2html-%{py3_ver}
fi

%files
%defattr(-,root,root,-)
%doc COPYING.txt FAQ.txt HISTORY.txt README.txt THANKS.txt BUGS.txt docs/* licenses
%ghost %{_bindir}/rst2html
%ghost %{_bindir}/rst2latex
%ghost %{_bindir}/rst2man
%ghost %{_bindir}/rst2odt
%ghost %{_bindir}/rst2odt_prepstyles
%ghost %{_bindir}/rst2pseudoxml
%ghost %{_bindir}/rst2s5
%ghost %{_bindir}/rst2xetex
%ghost %{_bindir}/rst2xml
%ghost %{_bindir}/rstpep2html
%{_bindir}/rst*-%{py3_ver}
%{python3_sitelib}/docutils/
%{python3_sitelib}/docutils-%{version}-py%{py3_ver}.egg-info

%changelog
* Sat Nov  8 2014 Led <ledest@gmail.com>
- fix bashism in pre script
* Tue Jul 15 2014 toddrme2178@gmail.com
- Update to 0.12
  * docs/ref/rst/directives.txt
  - Update "math" and "csv-table" descriptions.
  * docutils/parsers/rst/directives/images.py
  - Fix [258] figwidth="image" generates unitless width value.
  * docutils/parsers/rst/states.py
  - Improve error report when a non-ASCII character is specified as
    delimiter, quote or escape character under Python 2.
    Fixes [ 249 ] and [ 250 ].
  * docutils/writers/html4css1/__init__.py
  - Don't add newline after inline math.
    Thanks to Yury G. Kudryashov for the patch.
  * docutils/writers/latex2e/__init__.py
  - Fix [ 239 ] Latex writer glues paragraphs with figure floats.
  - Apply [ 116 ] by Kirill Smelkov. Don't hardcode \large for subtitle.
  * docutils/writers/odf_odt/__init__.py
  - Apply patch by Jakub Wilk to fix bug [ 100 ].
  * test/test_error_reporting.py
  - Fix [ 223 ] by removing redundant tests we do not have control over.
  * test/test_nodes.py
  - Apply [ 115 ] respect fixed 2to3 string literal conversion behavior.
* Tue Sep 24 2013 toddrme2178@gmail.com
- Update to 0.11
  * Fix for the overwritting of document attributes.
  * Support embedded aliases within hyperlink references.
  * try local import of docutils components (reader, writer, parser,
    language module) before global search.
  * Python 3.3 checks CVS syntax only if "strict" is True.
  * Now, it is easy to add a custom stylesheet to Docutils' default
    stylesheet with, e.g.,
  - -stylesheet_path='html4css1.css, mystyle.css'
  * If there is a file html4css1.css in the working directory of the
    process at launch, it is used instead of the one provided by
    Docutils in the writer source directory.
  * New default for math-output: HTML math.css.
  * Avoid repeated class declarations in html4css1 writer
  * Drop the simple algorithm replacing straight double quotes with
    English typographic ones. Activate the SmartQuotes transform if
    you want this feature.
  * New setting stylesheet_dirs: Comma-separated list of directories
    where stylesheets are found. Used by stylesheet_path when
    expanding relative path arguments.
  * handle lines starting with a period.
  * Fix option separating comma was bold (thanks to Bill Morris).
- Use pypi url and download
- Replace rpmlint-non-executable-scripts.diff with sed in the spec
  file
* Mon Sep 16 2013 tchvatal@suse.com
- Fix the symlink creation.
* Mon Sep 16 2013 tchvatal@suse.com
- Version bump to 0.10 to match py2 version.
  * SmartQuotes transform for typographic quotes and dashes.
  * FileInput/FileOutput: no system-exit on IOError. The handle_io_errors option is ignored.
  * <code> tag for inline "code", do not drop nested inline nodes (syntax highlight tokens).
  * Customizable MathJax URL (based on patch by Dmitry Shachnev).
  * No line break after opening inline math tag.
- Mask testsuite for now as it fail.
- Drop r7486-python33-compat.patch as it is not needed.
- Add rpmlint-non-executable-scripts.diff.
- Use update-alternatives for binaries so we can switch between
  py2 and py3.
* Tue Nov 20 2012 saschpe@suse.de
- Run testsuite
- Correctly fix non-excutable script warning
- Remove outdated macros
- Name Python3 binaries consistently:
  + Fix in setup.py to have correct egg-info data
* Fri Oct 26 2012 highwaystar.ru@gmail.com
- patch from upstream for python3.3 support
  * Fix [3541369] Relative __import__ also with Python 3.3
* Thu May  3 2012 toddrme2178@gmail.com
- Update to version 0.9:
  * reStructuredText "code" role and directive with syntax
    highlighting by Pygments_.
  * "code" option of the "include" directive.
  * Fix [ 3402314 ] allow non-ASCII whitespace, punctuation
    characters and "international" quotes around inline markup.
  * Fix handling of missing stylesheets.
  * Fix [ 2971827 ] and [ 3442827 ] extras/roman.py moved to
    docutils/utils/roman.py
  * docutils.utils is now a package (providing a place for
    sub-modules)
  * change default for `math-output` setting to MathJax
  * Support the `abbreviation` and `acronym` standard roles.
  * Record only files required to generate the LaTeX source as
    dependencies.
  * Use ``\setcounter{secnumdepth}{0}`` instead of ``*``-versions
    when suppressing LaTeX section numbering.
- Cleaned up spec files
- Fix rpmlint warnings
* Mon Apr 30 2012 cfarrell@suse.com
- license update: Python-2.0 and BSD-2-Clause and GPL-2.0+ and GPL-3.0+ and
  SUSE-Public-Domain
  tools/editors/emacs/rst.el is GPL-3.0+ - see also COPYING file
* Fri Apr 27 2012 toddrme2178@gmail.com
- Fix building python 3 package on openSUSE 11.4 x86_64
* Mon Apr 23 2012 toddrme2178@gmail.com
- Add python 3 package
